.. _all-salt.roster:

==============
roster modules
==============

.. currentmodule:: salt.roster

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    ansible
    cache
    cloud
    clustershell
    flat
    range
    scan
